embassy-net

Crates

git

Versions

default

Flavors

DhcpConfig

Struct DhcpConfig 

#[non_exhaustive]
pub struct DhcpConfig { pub max_lease_duration: Option<Duration>, pub retry_config: RetryConfig, pub ignore_naks: bool, pub server_port: u16, pub client_port: u16, pub hostname: Option<String<MAX_HOSTNAME_LEN>>, }
DHCP configuration.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
max_lease_duration: Option<Duration>

Maximum lease duration.

If not set, the lease duration specified by the server will be used. If set, the lease duration will be capped at this value.

retry_config: RetryConfig

Retry configuration.

ignore_naks: bool

Ignore NAKs from DHCP servers.

This is not compliant with the DHCP RFCs, since theoretically we must stop using the assigned IP when receiving a NAK. This can increase reliability on broken networks with buggy routers or rogue DHCP servers, however.

server_port: u16

Server port. This is almost always 67. Do not change unless you know what you’re doing.

client_port: u16

Client port. This is almost always 68. Do not change unless you know what you’re doing.

hostname: Option<String<MAX_HOSTNAME_LEN>>

Our hostname. This will be sent to the DHCP server as Option 12.